import pymssql


def sql_select(sql):
    connect = pymssql.connect('123.207.201.140', 'wfz', 'wfz@123456', 'py_test')  # 服务器名,账户,密码,数据库名
    if connect:
        print("连接成功!")
    cursor = connect.cursor()  # 创建一个游标对象,python里的sql语句都要通过cursor来执行
    # 1 插入数据表
    cursor.execute(sql)  # 执行sql语句
    row = cursor.fetchall()  # 读取查询结果,
    cursor.close()  # 关闭游标
    connect.close()  # 关闭连接
    return row


if __name__ == '__main__':
    sql = "select * from t_name"
    row = sql_select(sql)
    print(row)


#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
    reshapedata FJH
"""
import platform
from setuptools import setup
from setuptools import find_packages

setup(
    name='wfz_fjh',
    version='1.0.4',
    install_requires=[
        'requests',
    ],
    packages=find_packages(),
    license='Apache License',
    author='fjh',
    author_email='1160230887@qq.com',
    url='http://www.reshapedata.com',
    description='reshape data type in py language ',
    keywords=['reshapedata', 'rdt', 'wfz_fjh'],
    python_requires='>=3.6',
)
